@@ -2,7 +2,7 @@ package Tk::Photo;
 require Tk;
 
 use vars qw($VERSION @ISA);
-$VERSION = '3.005'; # $Id: //depot/Tk8/Photo/Photo.pm#5$
+$VERSION = '3.007'; # $Id: //depot/Tk8/Photo/Photo.pm#7$
 
 @ISA = qw(Tk::Image);
 
@@ -12,7 +12,7 @@ bootstrap Tk::Photo $Tk::VERSION;
 
 sub Tk_image { 'photo' }    
 
-Tk::Methods("blank","copy","get","put","read","redither","write");
+Tk::Methods("blank","copy","data","formats","get","put","read","redither","write");
 
 1;
 __END__
